@@ -28,7 +28,7 @@
 
 /* $Header: /home/daffy/u0/vern/flex/RCS/dfa.c,v 2.26 95/04/20 13:53:14 vern Exp $ */
 #include <sys/cdefs.h>
-__FBSDID("$FreeBSD: src/usr.bin/lex/dfa.c,v 1.6 2002/06/30 05:25:03 obrien Exp $");
+__FBSDID("$FreeBSD: src/usr.bin/lex/dfa.c,v 1.6.34.1 2009/04/15 03:14:26 kensmith Exp $");
 
 #include "flexdef.h"
 
