@@ -28,7 +28,7 @@
 
 /* $Header: /home/daffy/u0/vern/flex/RCS/gen.c,v 2.56 96/05/25 20:43:38 vern Exp $ */
 #include <sys/cdefs.h>
-__FBSDID("$FreeBSD: src/usr.bin/lex/gen.c,v 1.7 2004/01/06 18:54:55 nectar Exp $");
+__FBSDID("$FreeBSD: src/usr.bin/lex/gen.c,v 1.7.28.1 2009/04/15 03:14:26 kensmith Exp $");
 
 #include "flexdef.h"
 
