@@ -28,7 +28,7 @@
 
 /* $Header: /home/daffy/u0/vern/flex/RCS/tblcmp.c,v 2.11 94/11/05 17:08:28 vern Exp $ */
 #include <sys/cdefs.h>
-__FBSDID("$FreeBSD: src/usr.bin/lex/tblcmp.c,v 1.6 2002/06/30 05:25:04 obrien Exp $");
+__FBSDID("$FreeBSD: src/usr.bin/lex/tblcmp.c,v 1.6.34.1 2009/04/15 03:14:26 kensmith Exp $");
 
 #include "flexdef.h"
 
