@@ -40,7 +40,7 @@
  */
 
 #include <sys/cdefs.h>
-__FBSDID("$FreeBSD: src/usr.bin/make/dir.c,v 1.52 2005/03/23 12:56:15 harti Exp $");
+__FBSDID("$FreeBSD: src/usr.bin/make/dir.c,v 1.52.20.1 2009/04/15 03:14:26 kensmith Exp $");
 
 /*-
  * dir.c --
