@@ -37,7 +37,7 @@
  * SUCH DAMAGE.
  *
  *	@(#)job.h	8.1 (Berkeley) 6/6/93
- * $FreeBSD: src/usr.bin/make/job.h,v 1.46 2007/03/08 09:16:10 fjoe Exp $
+ * $FreeBSD: src/usr.bin/make/job.h,v 1.46.2.1.2.1 2009/04/15 03:14:26 kensmith Exp $
  */
 
 #ifndef job_h_4678dfd1
@@ -64,9 +64,10 @@ void Job_Make(struct GNode *);
 void Job_Init(int);
 Boolean Job_Full(void);
 Boolean Job_Empty(void);
-int Job_Finish(void);
+void Job_Finish(void);
 void Job_Wait(void);
 void Job_AbortAll(void);
+void Job_SetPrefix(void);
 
 void Proc_Init(void);
 
