@@ -40,7 +40,7 @@
  */
 
 #include <sys/cdefs.h>
-__FBSDID("$FreeBSD: src/usr.bin/make/util.c,v 1.19 2005/05/13 13:47:41 harti Exp $");
+__FBSDID("$FreeBSD: src/usr.bin/make/util.c,v 1.19.20.1 2009/04/15 03:14:26 kensmith Exp $");
 
 /*-
  * util.c --
