@@ -26,7 +26,7 @@
 
 #ifndef lint
 static const char rcsid[] =
-  "$FreeBSD: src/usr.sbin/btxld/btxld.c,v 1.10 2006/01/23 13:55:32 delphij Exp $";
+  "$FreeBSD: src/usr.sbin/btxld/btxld.c,v 1.10.8.1 2009/04/15 03:14:26 kensmith Exp $";
 #endif /* not lint */
 
 #include <sys/param.h>
