@@ -32,7 +32,7 @@
 static char sccsid[] = "@(#)mkmakefile.c	8.1 (Berkeley) 6/6/93";
 #endif
 static const char rcsid[] =
-  "$FreeBSD: src/usr.sbin/config/mkmakefile.c,v 1.91 2006/10/24 07:12:31 imp Exp $";
+  "$FreeBSD: src/usr.sbin/config/mkmakefile.c,v 1.91.2.2.2.1 2009/04/15 03:14:26 kensmith Exp $";
 #endif /* not lint */
 
 /*
@@ -110,7 +110,7 @@ makefile(void)
 {
 	FILE *ifp, *ofp;
 	char line[BUFSIZ];
-	struct opt *op;
+	struct opt *op, *t;
 	int versreq;
 
 	read_files();
@@ -127,8 +127,12 @@ makefile(void)
 	if (ofp == 0)
 		err(1, "%s", path("Makefile.new"));
 	fprintf(ofp, "KERN_IDENT=%s\n", ident);
-	SLIST_FOREACH(op, &mkopt, op_next)
-		fprintf(ofp, "%s=%s\n", op->op_name, op->op_value);
+	SLIST_FOREACH_SAFE(op, &mkopt, op_next, t) {
+		fprintf(ofp, "%s=%s", op->op_name, op->op_value);
+		while ((op = SLIST_NEXT(op, op_append)) != NULL)
+			fprintf(ofp, " %s", op->op_value);
+		fprintf(ofp, "\n");
+	}
 	if (debugging)
 		fprintf(ofp, "DEBUG=-g\n");
 	if (profiling)
@@ -735,7 +739,9 @@ do_rules(FILE *f)
 				printf("config: don't know rules for %s\n", np);
 				break;
 			}
-			snprintf(cmd, sizeof(cmd), "${%s_%c%s}", ftype,
+			snprintf(cmd, sizeof(cmd), "${%s_%c%s}\n"
+			    ".if defined(NORMAL_CTFCONVERT) && !empty(NORMAL_CTFCONVERT)\n"
+			    "\t${NORMAL_CTFCONVERT}\n.endif", ftype,
 			    toupper(och),
 			    ftp->f_flags & NOWERROR ? "_NOWERROR" : "");
 			compilewith = cmd;
