@@ -25,7 +25,7 @@
  */
 
 #include <sys/cdefs.h>
-__FBSDID("$FreeBSD: src/usr.sbin/mtree/specspec.c,v 1.6 2005/03/29 11:44:17 tobez Exp $");
+__FBSDID("$FreeBSD: src/usr.sbin/mtree/specspec.c,v 1.6.20.1 2009/04/15 03:14:26 kensmith Exp $");
 
 #include <err.h>
 #include <grp.h>
